@@ -6,7 +6,7 @@ use Fcntl qw(SEEK_END);
 use Digest::SHA qw(sha512);
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 BEGIN {
    eval {
@@ -49,11 +49,13 @@ sub data {
 }
 
 sub crt {
-   shift->{"crt"} = shift;
+   my $self = shift;
+   $self->{"crt"} = shift;
 }
 
 sub key {
-   shift->{"key"} = shift;
+   my $self = shift;
+   $self->{"key"} = shift;
 }
 
 sub crtFile {
@@ -341,7 +343,7 @@ ELF::sign - X509 signing of elf execuables
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =over 2
 
@@ -361,92 +363,30 @@ It uses SHA512 Hashing via PKCS#7 to ensure the correctness.
 
 =head1 SYNOPSIS
 
-=head2 Signing - File or inmemory based
-
 You can mix inmemory and file based commands.
 
-=over 2
-
-=item File based
-
-  use ELF::sign;
-  my $sign = ELF::sign->new();
-  $sign->dataFile($file);
-  $x->crtFile("test.crt");
-  $x->keyFile("test.key");
-  if (my $error = $x->sign()) {
-     print "  ERROR: sign: ".$error."\n";
-  } else {
-     print "  Signed.\n";
-  }
-  if (my $error = $x->save($outfile)) {
-     print "  ERROR: signFileInmemory->save: ".$error."\n";
-  }
-
-=back
-
-=over 2
-
-=item In-Memory based
+=head2 Signing
 
    use ELF::sign;
    my $sign = ELF::sign->new();
-   $sign->data(time());
-   $x->crt("-----BEGIN CERTIFICATE-----
-            ...
-            -----END CERTIFICATE-----");
-   $x->key("...");
-   if (my $error = $x->sign()) {
-      print "ERROR: sign: ".$error."\n";
-   } else {
-      print "Signed.\n";
-   }
-   my $signeddata = $x->get());
+   $sign->crtFile("test.crt");
+   $sign->keyFile("test.key");
+   $sign->dataFile($filename);
+   my $error = $sign->sign() ||
+               $sign->save($outfile);
+   die $error
+     if $error;
 
-=back
-
-=head2 Verifying - File or inmemory based
-
-You can mix inmemory and file based commands.
-
-=over 2
-
-=item File based
-
-  use ELF::sign;
-  my $sign = ELF::sign->new();
-  $sign->dataFile($file);
-  $x->crtFile("test.crt");
-  if (my $error = $x->verify()) {
-     print "ERROR: verify: ".$error."\n";
-     return;
-  } else {
-     print "Verified.\n";
-  }
-  if (my $error = $x->save($outfile, 1)) {
-     print "ERROR: save: ".$error."\n";
-  }
-
-=back
-
-=over 2
-
-=item In-Memory based
+=head2 Verifying
 
    use ELF::sign;
    my $sign = ELF::sign->new();
-   $sign->data(time());
-   $x->crt("-----BEGIN CERTIFICATE-----
-            ...
-            -----END CERTIFICATE-----");
-   if (my $error = $x->verify()) {
-      print "ERROR: verify: ".$error."\n";
-   } else {
-      print "Verified.\n";
-   }
-   my $signeddata = $x->get(1));
-
-=back
+   $sign->crtFile("test.crt");
+   $sign->dataFile($filename);
+   my $error = $sign->verify() ||
+               $sign->save($outfile, 1);
+   die $error
+     if $error;
 
 =head1 FUNCTIONS
 
@@ -525,7 +465,7 @@ Returns string data in hex format.
 
 Example:
 
-  perl -e 'use ELF::sign; print ELF::sign->hexdump("test")."\n";'
+  perl -e 'use ELF::sign; print ELF::sign::hexdump("test")."\n";'
   74:65:73:74
 
 =back
